@@ -3,7 +3,7 @@ from typing import List, Dict, Tuple, Union, Sequence
 from typing_extensions import Literal
 import numpy as np
 
-from fdsreader.utils import Surface, Extent, Quantity, Dimension
+from fdsreader.utils import Extent, Quantity, Dimension
 import fdsreader.utils.fortran_data as fdtype
 from fdsreader import settings
 
@@ -84,7 +84,7 @@ class Boundary:
     """Container for boundary data specific to one quantity.
 
     :ivar quantity: Quantity object containing information about the quantity calculated for this
-        :class:`Obstruction` with the corresponding label and unit.
+        :class:`Obstruction` with the corresponding short_name and unit.
     :ivar times: Numpy array containing all times for which data has been recorded.
     :ivar cell_centered: Indicates whether centered positioning for data is used.
     :ivar lower_bounds: Dictionary with lower bounds for each timestep with meshes as keys.
@@ -149,12 +149,12 @@ class SubObstruction:
 
     :ivar extent: :class:`Extent` object containing 3-dimensional extent information.
     :ivar bound_indices: Indices used to define obstruction bounds in terms of mesh locations.
-    :ivar side_surfaces: Tuple of six surfaces for each side of the cuboid.
+    :ivar side_surfaces: Tuple of six :class:`Surface`s for each side of the cuboid.
     :ivar hide_times: List with points in time from when on the SubObstruction will be hidden.
     :ivar show_times: List with points in time from when on the SubObstruction will be shown.
     """
 
-    def __init__(self, side_surfaces: Tuple[Surface, ...], bound_indices: Tuple[int, int, int, int, int, int],
+    def __init__(self, side_surfaces: Tuple, bound_indices: Tuple[int, int, int, int, int, int],
                  extent: Extent):
         self.extent = extent
         self.side_surfaces = side_surfaces
@@ -167,20 +167,21 @@ class SubObstruction:
         self.hide_times = list()
         self.show_times = list()
 
-    def _add_patches(self, bid: int, cell_centered: bool, quantity: str, label: str, unit: str, patches: List[Patch],
-                     times: np.ndarray, n_t: int, lower_bounds: np.ndarray, upper_bounds: np.ndarray):
+    def _add_patches(self, bid: int, cell_centered: bool, quantity: str, short_name: str, unit: str,
+                     patches: List[Patch], times: np.ndarray, n_t: int, lower_bounds: np.ndarray,
+                     upper_bounds: np.ndarray):
         if bid not in self._boundary_data:
-            self._boundary_data[bid] = Boundary(Quantity(quantity, label, unit), cell_centered, times, n_t, patches,
-                                                lower_bounds, upper_bounds)
+            self._boundary_data[bid] = Boundary(Quantity(quantity, short_name, unit), cell_centered, times, n_t,
+                                                patches, lower_bounds, upper_bounds)
 
         if not settings.LAZY_LOAD:
             _ = self._boundary_data[bid].data
 
     def get_data(self, quantity: Union[str, Quantity]):
-        if type(quantity) != str:
+        if type(quantity) == Quantity:
             quantity = quantity.name
         return next(b for b in self._boundary_data.values() if
-                    b.quantity.name.lower() == quantity.lower() or b.quantity.label.lower() == quantity.lower())
+                    b.quantity.name.lower() == quantity.lower() or b.quantity.short_name.lower() == quantity.lower())
 
     def __getitem__(self, item):
         if type(item) == int:
@@ -300,7 +301,7 @@ class Obstruction:
         :param orientation: Optionally filter by a specific orientation as well (-3=-z, -2=-y, -1=-x, 1=x, 2=y, 3=z).
             A value of 0 indicates to no filter.
         """
-        if type(quantity) != str:
+        if type(quantity) == Quantity:
             quantity = quantity.name
 
         ret = [subobst.get_data(quantity) for subobst in self._subobstructions]
@@ -344,4 +345,4 @@ class Obstruction:
 
     def __repr__(self, *args, **kwargs):
         return f"Obstruction(id={self.id}, Bounding-Box={self.bounding_box}, SubObstructions={len(self._subobstructions)}" + (
-            f", Quantities={[q.label for q in self.quantities]}" if self.has_boundary_data else "") + ")"
+            f", Quantities={[q.short_name for q in self.quantities]}" if self.has_boundary_data else "") + ")"
